"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createProgress = exports.writeResultsToFile = exports.createNewLogger = exports.parseGitContext = exports.exitWithError = exports.errormsg = exports.to = void 0;
const chalk_1 = require("chalk");
const debug_1 = __importDefault(require("debug"));
const progress_1 = __importDefault(require("progress"));
const fs_1 = require("fs");
exports.to = async (fn) => {
    try {
        let res;
        if (typeof fn === 'function') {
            res = await fn();
        }
        else {
            res = await fn;
        }
        return [null, res];
    }
    catch (error) {
        return [error, null];
    }
};
exports.errormsg = (msg) => {
    return chalk_1.red `error: ` + msg;
};
exports.exitWithError = (msg) => {
    console.error(exports.errormsg(msg));
    // eslint-disable-next-line unicorn/no-process-exit
    process.exit(1);
};
exports.parseGitContext = (gitContextStr) => {
    const isBase64 = /^([\d+/A-Za-z]{4})*([\d+/A-Za-z]{3}=|[\d+/A-Za-z]{2}==)?$/;
    if (isBase64.test(gitContextStr)) {
        gitContextStr = Buffer.from(gitContextStr, 'base64').toString('utf-8');
    }
    try {
        const gitContext = JSON.parse(gitContextStr);
        return gitContext;
    }
    catch (error) {
        exports.exitWithError(`could not parse git context json, with error ${error}`);
    }
};
exports.createNewLogger = (namespace) => {
    const logger = debug_1.default(namespace);
    return {
        info: (msg) => logger('[%s] level: %s, msg: %s', new Date().toISOString(), 'info', msg),
        warn: (msg) => logger('[%s] level: %s, msg: %s', new Date().toISOString(), 'warn', msg),
        debug: (msg) => logger('[%s] level: %s, msg: %s', new Date().toISOString(), 'debug', msg),
        error: (msg) => logger('[%s] level: %s, msg: %s', new Date().toISOString(), 'error', msg),
    };
};
exports.writeResultsToFile = async (fileName, data) => {
    const [writeErr] = await exports.to(async () => fs_1.writeFileSync(fileName, data));
    if (writeErr) {
        exports.exitWithError(`failed to write result to file ${fileName}", ${writeErr}`);
    }
};
exports.createProgress = (resourceName, total, refreshMs = 200) => {
    const progressBar = new progress_1.default(`fetching ${resourceName} (:current/:total) [:bar] :percent eta=:etas elapsed=:elapsed`, {
        total,
        complete: '=',
        incomplete: ' ',
        width: 30,
    });
    const interval = setInterval(() => {
        progressBar.render();
        if (progressBar.complete) {
            clearInterval(interval);
        }
    }, refreshMs);
    const makeTick = (n = 1) => {
        progressBar.tick(n);
    };
    return { tick: makeTick }; // return a simple interface
};
//# sourceMappingURL=index.js.map